=== added file 'bzrlib/symbol_versioning.py'
--- bzrlib/symbol_versioning.py	1970-01-01 00:00:00 +0000
+++ bzrlib/symbol_versioning.py	2006-01-05 10:49:26 +0000
@@ -0,0 +1,58 @@
+# Copyright (C) 2006 by Canonical Ltd
+#   Authors: Robert Collins <robert.collins@canonical.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Symbol versioning
+
+The methods here allow for api symbol versioning.
+"""
+
+__all__ = ['warn', 'set_warning_method', 'zero_seven']
+
+from warnings import warn
+
+
+zero_seven = "%s was deprecated in version 0.7"
+
+
+def set_warning_method(method):
+    """Set the warning method to be used by this module.
+
+    It should take a message and a warning category as warnings.warn does.
+    """
+    global warn
+    warn = method
+
+
+def deprecated_method(deprecation_version):
+    """Decorate a method so that use of it will trigger a warning.
+    
+    To deprecate an entire class, decorate __init__.
+    """
+
+    def method_decorator(callable):
+        """This is the function python calls to perform the decoration."""
+        
+        def decorated_method(self, *args, **kwargs):
+            """This is the decorated method."""
+            symbol = "%s.%s.%s" % (self.__class__.__module__, 
+                                   self.__class__.__name__,
+                                   callable.__name__
+                                   )
+            warn(deprecation_version % symbol, DeprecationWarning)
+            return callable(self, *args, **kwargs)
+        return decorated_method
+    return method_decorator

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2005-12-29 02:36:07 +0000
+++ bzrlib/tests/__init__.py	2006-01-05 10:49:26 +0000
@@ -691,6 +691,7 @@
                    'bzrlib.tests.test_source',
                    'bzrlib.tests.test_status',
                    'bzrlib.tests.test_store',
+                   'bzrlib.tests.test_symbol_versioning',
                    'bzrlib.tests.test_testament',
                    'bzrlib.tests.test_trace',
                    'bzrlib.tests.test_transactions',

=== modified file 'bzrlib/tests/test_sampler.py'
--- bzrlib/tests/test_sampler.py	2005-11-23 15:44:24 +0000
+++ bzrlib/tests/test_sampler.py	2006-01-05 10:49:26 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2006 by Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify

=== added file 'bzrlib/tests/test_symbol_versioning.py'
--- bzrlib/tests/test_symbol_versioning.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_symbol_versioning.py	2006-01-05 10:49:26 +0000
@@ -0,0 +1,51 @@
+# Copyright (C) 2006 by Canonical Ltd
+#   Authors: Robert Collins <robert.collins@canonical.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Symbol versioning tests."""
+
+import bzrlib.symbol_versioning as symbol_versioning
+from bzrlib.tests import TestCase
+
+
+
+class TestDeprecationWarnings(TestCase):
+
+    def capture_warning(self, message, category):
+        self._warnings.append((message, category))
+
+    def setUp(self):
+        super(TestDeprecationWarnings, self).setUp()
+        self._warnings = []
+    
+    @symbol_versioning.deprecated_method(symbol_versioning.zero_seven)
+    def deprecated_method(self):
+        return
+
+    def test_deprecated_method(self):
+        old_warning_method = symbol_versioning.warn
+        expected_warning = (
+            "bzrlib.tests.test_symbol_versioning.TestDeprecationWarnings.deprecated_method "
+            "was deprecated in version 0.7", DeprecationWarning)
+        try:
+            symbol_versioning.set_warning_method(self.capture_warning)
+            self.deprecated_method()
+            self.assertEqual([expected_warning], self._warnings)
+            self.deprecated_method()
+            self.assertEqual([expected_warning, expected_warning],
+                             self._warnings)
+        finally:
+            symbol_versioning.set_warning_method(old_warning_method)

